;; ┌─┐┬─┐┌─┐┌─┐┬ ┬┬┌─┐┌─┐
;; │ ┬├┬┘├─┤├─┘├─┤││  └─┐
;; └─┘┴└─┴ ┴┴  ┴ ┴┴└─┘└─┘
;;       ┌─┐┌┐┌┌┬┐       
;;       ├─┤│││ ││       
;;       ┴ ┴┘└┘─┴┘       
;;     ┌┬┐┌─┐┌┬┐┌─┐      
;;      ││├─┤ │ ├─┤      
;;     ─┴┘┴ ┴ ┴ ┴ ┴      

;; load in the s-exp of graphics and pet data

(load "~/hobbies/uwu/version-1/uwu-graphics.el")

;; ┬┌─┌─┐┬ ┬┌┬┐┌─┐┌─┐
;; ├┴┐├┤ └┬┘│││├─┤├─┘
;; ┴ ┴└─┘ ┴ ┴ ┴┴ ┴┴  

(defvar uwu-mode-map
  (let ((map (make-sparse-keymap)))
    ;; scroll back one pet, inside the pet viewer
    (define-key map (kbd "r") #'uwu--previous-pet)
    (define-key map (kbd "s") #'uwu--next-pet)
    map)
  "Keymap for `uwu-mode'.")

;; ┌┬┐┌─┐ ┬┌─┐┬─┐ 
;; │││├─┤ ││ │├┬┘ 
;; ┴ ┴┴ ┴└┘└─┘┴└─ 
;; ┌┬┐┌─┐┌┬┐┌─┐   
;; ││││ │ ││├┤    
;; ┴ ┴└─┘─┴┘└─┘   
;; ┌─┐┌─┐┌┬┐┬ ┬┌─┐
;; └─┐├┤  │ │ │├─┘
;; └─┘└─┘ ┴ └─┘┴  

(defgroup uwu nil
  "A virtual pet simulator."
  :group 'games)

(defcustom uwu-mode-hook nil
  "Hook run when entering uwu mode."
  :type 'hook
  :group 'uwu)

(define-derived-mode uwu-mode fundamental-mode "uwu"
  "The major mode of the uwu virtual pet simulator")

;; ┬  ┬┌─┐┬─┐┬┌─┐┌┐ ┬  ┌─┐┌─┐
;; └┐┌┘├─┤├┬┘│├─┤├┴┐│  ├┤ └─┐
;;  └┘ ┴ ┴┴└─┴┴ ┴└─┘┴─┘└─┘└─┘

(defvar *pet-shop-choice* nil)
(defvar *movement* 0)

;; ┌─┐┬ ┬┌┐┌┌─┐┌┬┐┬┌─┐┌┐┌┌─┐
;; ├┤ │ │││││   │ ││ ││││└─┐
;; └  └─┘┘└┘└─┘ ┴ ┴└─┘┘└┘└─┘

(defun pet-movement (pet-gfx)

  (let ((rng-move (random 5)))

    (cond ((and
	    (= 3 rng-move)
	    (> *movement* 0))

	   (decf *movement*))

	  (
	   (and
	    (= 4 rng-move)
	    (< *movement* 9))

	   (incf *movement*)))

    (print "╔═════════════════════╗" (get-buffer "*uwu-visualiser*"))
    
    (print
     (concat
      (substring "         " *movement*)

      (nth
       rng-move
       (cdr pet-gfx))) ; here we use the CDR of the gfx key-value
		       ; field, which gives us the graphics, and
		       ; eliminates the 'key' element.
     
     (get-buffer "*uwu-visualiser*"))

    (print "╚═════════════════════╝" (get-buffer "*uwu-visualiser*"))))

(defun blank-and-draw-frame (pet-gfx)
  (set-buffer "*uwu-visualiser*")
  (erase-buffer)
  (pet-movement pet-gfx))

(defun adult-pet-gfx-lookup (alignment skill genus)
      
    (assoc 'gfx
	   (assoc genus
		  (assoc skill
			 (assoc alignment +adult-data+)))))

(defun switch-pet-gfx (alignment skill genus)

  (pet-movement (adult-pet-gfx-lookup alignment skill genus)))

(defun one-frame-of-animation (alignment skill genus)

  (blank-and-draw-frame (adult-pet-gfx-lookup alignment skill genus)))

(defvar alignment-idle 'lawful)
(defvar skill-idle 'smart)
(defvar genus-idle 'normie)
	 

(defun uwu--window-setup ()
  
  (display-buffer
   (get-buffer-create "*uwu-visualiser*")
                  '(display-buffer-same-window . (())))

  (display-buffer
   (get-buffer-create "*human-pet-interaction*")
		  '(display-buffer-below-selected . (()))))

(defun uwu-visualiser ()
  (loop
   (
   (sleep 0.5)
   (when))

;;; ╔═════════════════════╗
;;; <@(･ω･o< )@     
;;; ╚═════════════════════╝

;; ┌─┐┌─┐┌─┐┬┌─┌─┐┌─┐┌─┐
;; ├─┘├─┤│  ├┴┐├─┤│ ┬├┤ 
;; ┴  ┴ ┴└─┘┴ ┴┴ ┴└─┘└─┘

;; provide package

(provide 'uwu)